@@ -120,7 +120,40 @@ class BaseHandler(RequestHandler):
         :return:
         """
         self.set_status(204)
-        self.finish()
+        await self.finish()
+
+    async def put(self):
+        """
+        重写父类put请求方法，使其支持通过URL进行方法调用
+        改造Tornado 调用处理方式，不在是一个url对应一个类处理，而是使用同实体处理放到一个类中
+        通过不同的url指向不同处理方法
+        :return:
+        """
+        logging.info(f"Request-Id: {self.request.headers.get('Request-Id', '')}")
+        self.process_request(self.request)
+        await self.request_handler()
+
+    async def delete(self):
+        """
+        重写父类delete请求方法，使其支持通过URL进行方法调用
+        改造Tornado 调用处理方式，不在是一个url对应一个类处理，而是使用同实体处理放到一个类中
+        通过不同的url指向不同处理方法
+        :return:
+        """
+        logging.info(f"Request-Id: {self.request.headers.get('Request-Id', '')}")
+        self.process_request(self.request)
+        await self.request_handler()
+
+    async def patch(self):
+        """
+        重写父类delete请求方法，使其支持通过URL进行方法调用
+        改造Tornado 调用处理方式，不在是一个url对应一个类处理，而是使用同实体处理放到一个类中
+        通过不同的url指向不同处理方法
+        :return:
+        """
+        logging.info(f"Request-Id: {self.request.headers.get('Request-Id', '')}")
+        self.process_request(self.request)
+        await self.request_handler()
 
     async def request_handler(self):
         # 通过url路径获取对应的处理方法
